@@ -24,19 +24,20 @@ module Zip
 
     # Opens the indicated zip file. If a file with that name already
     # exists it will be overwritten.
-    def initialize(file_name, stream=false)
+    def initialize(file_name, stream = false, encrypter = nil)
       super()
       @file_name = file_name
       @output_stream = if stream
                          iostream = @file_name.dup
-                         iostream.reopen
+                         iostream.reopen(@file_name)
                          iostream.rewind
                          iostream
                        else
-                         ::File.new(@file_name, "wb")
+                         ::File.new(@file_name, 'wb')
                        end
       @entry_set = ::Zip::EntrySet.new
       @compressor = ::Zip::NullCompressor.instance
+      @encrypter = encrypter || ::Zip::NullEncrypter.new
       @closed = false
       @current_entry = nil
       @comment = nil
@@ -46,17 +47,17 @@ module Zip
     # stream is passed to the block and closed when the block
     # returns.
     class << self
-      def open(file_name)
+      def open(file_name, encrypter = nil)
         return new(file_name) unless block_given?
-        zos = new(file_name)
+        zos = new(file_name, false, encrypter)
         yield zos
       ensure
         zos.close if zos
       end
 
       # Same as #open but writes to a filestream instead
-      def write_buffer(io = ::StringIO.new(''))
-        zos = new(io, true)
+      def write_buffer(io = ::StringIO.new(''), encrypter = nil)
+        zos = new(io, true, encrypter)
         yield zos
         zos.close_buffer
       end
@@ -85,7 +86,7 @@ module Zip
     # Closes the current entry and opens a new for writing.
     # +entry+ can be a ZipEntry object or a string.
     def put_next_entry(entry_name, comment = nil, extra = nil, compression_method = Entry::DEFLATED, level = Zip.default_compression)
-      raise Error, "zip stream is closed" if @closed
+      raise Error, 'zip stream is closed' if @closed
       if entry_name.kind_of?(Entry)
         new_entry = entry_name
       else
@@ -93,7 +94,7 @@ module Zip
       end
       new_entry.comment = comment unless comment.nil?
       unless extra.nil?
-        new_entry.extra = ExtraField === extra ? extra : ExtraField.new(extra.to_s)
+        new_entry.extra = extra.is_a?(ExtraField) ? extra : ExtraField.new(extra.to_s)
       end
       new_entry.compression_method = compression_method unless compression_method.nil?
       init_next_entry(new_entry, level)
@@ -102,8 +103,8 @@ module Zip
 
     def copy_raw_entry(entry)
       entry = entry.dup
-      raise Error, "zip stream is closed" if @closed
-      raise Error, "entry is not a ZipEntry" unless entry.is_a?(Entry)
+      raise Error, 'zip stream is closed' if @closed
+      raise Error, 'entry is not a ZipEntry' unless entry.is_a?(Entry)
       finalize_current_entry
       @entry_set << entry
       src_pos = entry.local_header_offset
@@ -126,6 +127,8 @@ module Zip
       @current_entry.compressed_size = @output_stream.tell - @current_entry.local_header_offset - @current_entry.calculate_local_header_size
       @current_entry.size = @compressor.size
       @current_entry.crc = @compressor.crc
+      @output_stream << @encrypter.data_descriptor(@current_entry.crc, @current_entry.compressed_size, @current_entry.size)
+      @current_entry.gp_flags |= @encrypter.gp_flags
       @current_entry = nil
       @compressor = ::Zip::NullCompressor.instance
     end
@@ -134,13 +137,15 @@ module Zip
       finalize_current_entry
       @entry_set << entry
       entry.write_local_entry(@output_stream)
+      @encrypter.reset!
+      @output_stream << @encrypter.header(entry.mtime)
       @compressor = get_compressor(entry, level)
     end
 
     def get_compressor(entry, level)
       case entry.compression_method
       when Entry::DEFLATED then
-        ::Zip::Deflater.new(@output_stream, level)
+        ::Zip::Deflater.new(@output_stream, level, @encrypter)
       when Entry::STORED then
         ::Zip::PassThruCompressor.new(@output_stream)
       else
@@ -172,11 +177,10 @@ module Zip
     public
 
     # Modeled after IO.<<
-    def << (data)
+    def <<(data)
       @compressor << data
       self
     end
-
   end
 end
 
